MCD protected
Agence ( id. agence, nom agence )

- Le champ id. agence constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Agence.
- Le champ nom agence était déjà un simple attribut de l'entité Agence.

Direction régionale ( id. dir., nom dir. )

- Le champ id. dir. constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Direction régionale.
- Le champ nom dir. était déjà un simple attribut de l'entité Direction régionale.

Superviser ( #id. agence, #id. dir.! )

- Avertissement. Table résultant de la conversion forcée d'une association DF.
- Le champ id. agence constitue la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité Agence.
- Le champ à saisie obligatoire id. dir. est une clé étrangère. Il a migré directement à partir de l'entité Direction régionale en perdant son caractère identifiant.